@@ -864,10 +864,21 @@ class Askdata(SignUp):
             for condition in join_conditions:
                 left_conditions.append(condition["left_on"])
                 right_conditions.append(condition["right_on"])
+            left_conditions = self.__retrieve_og_columns(left_conditions, df)
+            right_conditions = self.__retrieve_og_columns(right_conditions, df_query)
             return df.merge(df_query, how, None, left_conditions, right_conditions)
 
         return df.merge(df_query, how, on, left_on, right_on)
 
+    def __retrieve_og_columns(self, conditions:list, df:pd.DataFrame):
+        formatted_conditions = []
+        for condition in conditions:
+            for column in df.columns:
+                if condition in column.lower():
+                    formatted_conditions.append(column)
+
+        return formatted_conditions
+
     def get_join_info(self, df1: pd.DataFrame, df2: pd.DataFrame):
         return self.__get_join_info(df1, df2)
 
