@@ -34,7 +34,7 @@ class Insight_Definition:
         self.slug = defintion["slug"]
         self.icon = defintion["icon"]
         self.components: list = defintion["components"]
-
+        self._env = env
         self._token = token
 
         if env.lower() == 'dev':
@@ -1258,14 +1258,39 @@ class Insight_Definition:
         r = s.post(url=url, json=body, headers=headers)
         r.raise_for_status()
 
-    def clone(self, channel_id, card_name=""):
+    def clone(self, channel_id, card_name="", card_slug=None):
 
         if card_name == "":
             card_name = "Copy of " + self.name
+
+        if card_slug != None:
+            try:
+                url = self.smart_insight_url + "/definitions/agent/" + self.agent_id + "/slug/" + card_slug
+
+                s = requests.Session()
+                s.keep_alive = False
+                retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+                s.mount('https://', HTTPAdapter(max_retries=retries))
+
+                headers = {
+                    "Content-Type": "application/json",
+                    "Authorization": "Bearer" + " " + self._token
+                }
+                r = s.get(url=url, headers=headers)
+                r.raise_for_status()
+
+                definition = r.json()
+                insight_definition = Insight_Definition(self._env, self._token, definition)
+                insight_definition.delete()
+            except:
+                logging.info("{} card not found... creating new one".format(card_slug))
+
+
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/clone"
         body = {
             "agentId": self.agent_id,
             "name": card_name,
+            "slug": card_slug,
             "channelId": channel_id
             }
 
